@@ -16,37 +16,45 @@ impl ImagePageWidget {
 
     fn init(&self, resource_uri: &str, head: String, body: String) {
         self.widget.set_property_expand(true);
+        self.widget.get_style_context().add_class("page");
         self.widget.set_halign(gtk::Align::Fill);
         self.widget.set_valign(gtk::Align::Fill);
 
-        let container = gtk::Box::new(gtk::Orientation::Vertical, 12);
-        container.set_halign(gtk::Align::Center);
-        container.set_valign(gtk::Align::Center);
-        container.set_vexpand(true);
-        container.set_margin_bottom(48);
-        container.set_margin_top(12);
-        container.set_margin_start(12);
-        container.set_margin_end(12);
+        let container = gtk::BoxBuilder::new()
+            .orientation(gtk::Orientation::Vertical)
+            .spacing(12)
+            .halign(gtk::Align::Center)
+            .valign(gtk::Align::Center)
+            .vexpand(true)
+            .margin_bottom(48)
+            .margin_top(12)
+            .margin_start(12)
+            .margin_end(12)
+            .build();
 
         let image = gtk::Image::from_resource(&resource_uri);
         image.set_valign(gtk::Align::Start);
         image.show();
         container.add(&image);
 
-        let head_label = gtk::Label::new(Some(&head));
-        head_label.set_justify(gtk::Justification::Center);
-        head_label.set_valign(gtk::Align::Center);
-        head_label.set_margin_top(36);
+        let head_label = gtk::LabelBuilder::new()
+            .label(&head)
+            .justify(gtk::Justification::Center)
+            .valign(gtk::Align::Center)
+            .margin_top(36)
+            .build();
         head_label.get_style_context().add_class("page-title");
         head_label.show();
         container.add(&head_label);
 
-        let body_label = gtk::Label::new(Some(&body));
-        body_label.set_lines(2);
-        body_label.set_property_wrap(true);
-        body_label.set_justify(gtk::Justification::Center);
-        body_label.set_valign(gtk::Align::Center);
-        body_label.set_margin_top(12);
+        let body_label = gtk::LabelBuilder::new()
+            .label(&body)
+            .lines(2)
+            .wrap(true)
+            .justify(gtk::Justification::Center)
+            .valign(gtk::Align::Center)
+            .margin_top(12)
+            .build();
         body_label.get_style_context().add_class("page-body");
         body_label.show();
         container.add(&body_label);
