@@ -42,13 +42,14 @@ impl Window {
         if PROFILE == "Devel" {
             self.widget.get_style_context().add_class("devel");
         }
-        self.paginator.borrow_mut().add_page(WelcomePageWidget::new().widget.upcast::<gtk::Widget>());
-
+        self.paginator
+            .borrow_mut()
+            .add_page(WelcomePageWidget::new().widget.upcast::<gtk::Widget>());
         self.paginator.borrow_mut().add_page(
             ImagePageWidget::new(
-                "/org/gnome/Tour/activities.svg",
-                gettext("Open Activities to launch apps"),
-                gettext("The activities view can also be used to switch windows and search."),
+                "/org/gnome/Tour/overview.svg",
+                gettext("Get an Overview"),
+                gettext("Press Activities to see open windows and apps."),
             )
             .widget
             .upcast::<gtk::Widget>(),
@@ -56,9 +57,9 @@ impl Window {
 
         self.paginator.borrow_mut().add_page(
             ImagePageWidget::new(
-                "/org/gnome/Tour/search.svg",
-                gettext("Just type to search"),
-                gettext("In the activities view, just start typing to search for apps, settings and more."),
+                "/org/gnome/Tour/makeyourown.svg",
+                gettext("Make Apps Your Own"),
+                gettext("Arrange the app grid to your liking."),
             )
             .widget
             .upcast::<gtk::Widget>(),
@@ -66,9 +67,9 @@ impl Window {
 
         self.paginator.borrow_mut().add_page(
             ImagePageWidget::new(
-                "/org/gnome/Tour/calendar.svg",
-                gettext("Click the time to see notifications"),
-                gettext("The notifications popover also includes personal planning tools."),
+                "/org/gnome/Tour/workspaces.svg",
+                gettext("Keep on Top with Workspaces"),
+                gettext("Easily organise windows with the new workspaces view."),
             )
             .widget
             .upcast::<gtk::Widget>(),
@@ -76,9 +77,9 @@ impl Window {
 
         self.paginator.borrow_mut().add_page(
             ImagePageWidget::new(
-                "/org/gnome/Tour/status-menu.svg",
-                gettext("View system information and settings"),
-                gettext("Get an overview of the system status and quickly change settings."),
+                "/org/gnome/Tour/blank.svg",
+                gettext("Up/Down for the Overview"),
+                gettext("On a touchpad, use three-finger vertical swipes. Try it!"),
             )
             .widget
             .upcast::<gtk::Widget>(),
@@ -86,23 +87,29 @@ impl Window {
 
         self.paginator.borrow_mut().add_page(
             ImagePageWidget::new(
-                "/org/gnome/Tour/software.svg",
-                gettext("Use Software to find and install apps"),
-                gettext("Discover great apps through search, browsing and our recommendations."),
+                "/org/gnome/Tour/blank.svg",
+                gettext("Left/Right for Workspaces"),
+                gettext("On a touchpad, use three-finger horizontal swipes. Try it!"),
             )
             .widget
             .upcast::<gtk::Widget>(),
         );
 
         let name = glib::get_os_info("NAME").unwrap_or_else(|| "GNOME".into());
+        let version = glib::get_os_info("VERSION").unwrap_or_else(|| "".into());
         let last_page = ImagePageWidget::new(
             "/org/gnome/Tour/ready-to-go.svg",
-            // Translators: The following string is formated as "We hope that you enjoy GNOME"
-            i18n_f("That's it! We hope that you enjoy {}.", &[&name]),
+            // Translators: The following string is formatted as "We hope that you enjoy GNOME 40"
+            i18n_f(
+                "That's it! We hope that you enjoy {} {}.",
+                &[&name, &version],
+            ),
             gettext("To get more advice and tips, see the Help app."),
         );
         last_page.widget.get_style_context().add_class("last-page");
-        self.paginator.borrow_mut().add_page(last_page.widget.upcast::<gtk::Widget>());
+        self.paginator
+            .borrow_mut()
+            .add_page(last_page.widget.upcast::<gtk::Widget>());
 
         self.widget.add(&self.paginator.borrow().widget);
     }
